.. include:: ../README.rst
  :end-before: _documentation

Installation and Upgrade
========================

.. toctree::
   :maxdepth: 1

   Installation <installation>

Using Molecule
==============

.. toctree::
   :maxdepth: 1

   Getting Started <getting-started>
   CI/CD Usage <ci>
   Command Line Reference <usage>
   Configuration <configuration>

Common Molecule Use Cases
=========================

.. toctree::
   :maxdepth: 1

   Common Use Cases <examples>
   Frequently Asked Questions <faq>

Contributing to Molecule
========================

.. toctree::
   :maxdepth: 1

   Contributing <contributing>


References and Appendices
=========================

* :ref:`genindex`

External Resources
==================

Below you can see a list of useful articles and presentations, recently updated
being listed first:

- `Ansible Collections: Role Tests with Molecule <https://ericsysmin.com/2020/04/30/ansible-collections-role-tests-with-molecule/>`_ `@ericsysmin`
- `Molecule v3 Slides <https://sbarnea.com/slides/molecule/#/>`_ `@ssbarnea`.
- `Testing your Ansible roles with Molecule <https://www.jeffgeerling.com/blog/2018/testing-your-ansible-roles-molecule>`_ `@geerlinguy`
- `How to test Ansible and don’t go nuts <https://www.goncharov.xyz/it/ansible-testing-en.html>`_ `@ultral`

.. When updating the list remember to remove broken links or outdated content
   that is no longer appliable to current versions. If older articles are
   updated to match latest versions move them up.
